@@ -22,11 +22,10 @@ import pytest
 from invenio_db import db
 from invenio_files_rest.errors import InvalidOperationError
 from invenio_files_rest.models import Bucket, FileInstance, ObjectVersion
-from invenio_records_resources.services.files import FileService
 from marshmallow.exceptions import ValidationError
 from mock_module.models import DraftMetadata, FileDraftMetadata, \
     FileRecordMetadata
-from mock_module.service import DraftFileServiceConfig, ServiceConfig
+from mock_module.service import ServiceConfig
 
 from invenio_drafts_resources.services import RecordService
 
@@ -41,8 +40,8 @@ def input_data(input_data):
     return input_data
 
 
-@pytest.fixture()
-def service(appctx, location, file_service, draft_file_service):
+@pytest.fixture(scope="module")
+def service(file_service, draft_file_service):
     """Service instance."""
     return RecordService(
         ServiceConfig,
@@ -51,6 +50,16 @@ def service(appctx, location, file_service, draft_file_service):
     )
 
 
+@pytest.fixture(scope="module")
+def base_app(base_app, service, file_service, draft_file_service):
+    """Application factory fixture."""
+    registry = base_app.extensions['invenio-records-resources'].registry
+    registry.register(service, service_id='mock-records-service')
+    registry.register(file_service, service_id='mock-files-service')
+    registry.register(draft_file_service, service_id='mock-draftfiles-service')
+    yield base_app
+
+
 #
 # Helpers
 #
